<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!--
   +==========================================================================+
   | Copyright 2002, 2003 Rational Software Corporation.  All Rights Reserved.|
   | This software contains proprietary and confidential information of       |
   | Rational and its suppliers.  Use, disclosure or reproduction is          |
   | prohibited without the prior express written consent of Rational.        |
   +==========================================================================+
-->

<!-- ******************************************************************** 
     Id: ccnet_infopane.xsl

     Together with ccnet_infopane.htm, this file provides and formats content 
     for the Rational ClearCase Explorer's Information Pane, when displayed 
     in the ClearCase Integration with Microsoft Visual Studio .NET.
     ******************************************************************** -->


<xsl:template match="/">

  <xsl:apply-templates/>

</xsl:template>


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
     Detect multiple or no selection by user, indicated by type='nothing'. Otherwise we have a selection.
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<xsl:template match="items">

  <xsl:apply-templates/>

</xsl:template>


<xsl:template match="item">

  <xsl:choose> 

    <xsl:when test="@type='nothing'">

       <xsl:call-template name="item.nolist"/>

    </xsl:when>

    <xsl:otherwise>

       <xsl:call-template name="item.maintable"/>

    </xsl:otherwise>

  </xsl:choose> 

</xsl:template>


<xsl:template name="item.nolist">

  <DIV CLASS="divindent">

    <xsl:choose>

      <xsl:when test="ucm[.='1']">

        <xsl:choose>                

          <xsl:when test="integration[.='1']">

            <xsl:choose>

              <xsl:when test="snapshot[.='1']">

                 <xsl:apply-templates select="." mode="ucm.integration.snapshot.view"/>

              </xsl:when>

              <xsl:otherwise>

                 <xsl:apply-templates select="." mode="ucm.integration.dynamic.view"/>

              </xsl:otherwise>

            </xsl:choose>

          </xsl:when>

          <xsl:otherwise>

            <xsl:choose>

              <xsl:when test="snapshot[.='1']">

                 <xsl:apply-templates select="." mode="ucm.development.snapshot.view"/>

              </xsl:when>

              <xsl:otherwise>

                 <xsl:apply-templates select="." mode="ucm.development.dynamic.view"/>

              </xsl:otherwise>

            </xsl:choose>                

          </xsl:otherwise>

        </xsl:choose>                

      </xsl:when>

    <xsl:otherwise>     <!-- Non-UCM views -->

      <xsl:choose>                

        <xsl:when test="snapshot[.='1']">

          <xsl:apply-templates select="." mode="base.snapshot.view"/>

        </xsl:when>

        <xsl:otherwise>

          <xsl:apply-templates select="." mode="base.dynamic.view"/>

        </xsl:otherwise>

      </xsl:choose>                 

    </xsl:otherwise>                

    </xsl:choose>                

  </DIV>

</xsl:template>


<xsl:template name="item.maintable">

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Main table containing title, navigation tabs, and two nested tables
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

  <TABLE BORDER="0" CELLSPACING="0" CELLPADDING="0" WIDTH="100%">

    <TR VALIGN="TOP">

      <TD HEIGHT="20" VALIGN="MIDDLE" BGCOLOR="#C0C0C0" STYLE="font-size: 10pt; font-weight: bold; color: #000080">

        <IMG ALIGN="ABSMIDDLE" SRC="object.gif" BORDER="0" ALT=""/>

        選択

      </TD>

      <TD HEIGHT="20" NOWRAP="NOWRAP" VALIGN="BOTTOM" STYLE="background-color: #C0C0C0">   

        <SPAN STYLE="cursor: hand" ONCLICK="change_abouttab();">

          <IMG NAME="image1" SRC="abouttab-on.gif" ALT="選択内容についての情報" WIDTH="71" HEIGHT="12" BORDER="0" ALIGN="ABSBOTTOM"/>

        </SPAN>

        <SPAN STYLE="cursor: hand" ONCLICK="change_usestab();">

          <IMG NAME="image2" SRC="usestab-off.gif" ALT="選択によってできること" WIDTH="71" HEIGHT="12" BORDER="0" ALIGN="ABSBOTTOM"/>

        </SPAN>

      </TD>

    </TR>

    <TR>

      <TD VALIGN="TOP" ALIGN="LEFT" WIDTH="230">


    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
         Nested left table listing properties of selected item
         +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

        <TABLE BORDER="0" CELLSPACING="5" WIDTH="220" STYLE="border-top: none; border-right: 1px #000080 solid; border-bottom: none; border-left: none;">

          <xsl:apply-templates select="*" mode="item.props"/>

        </TABLE>

      </TD>
  
      <TD VALIGN="TOP">

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
         Nested right table about item and uses
         +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

        <TABLE BORDER="0" CELLSPACING="5" WIDTH="100%" ALIGN="TOP">

          <TR><TD>

              <DIV ID="elemAbout" STYLE="position:absolute, top:0; left:0">

                <xsl:apply-templates select="*" mode="item.about"/>

              </DIV>

              <DIV STYLE="position: relative; left: 0; display: none" ID="elemUses">

                <xsl:apply-templates select="*" mode="item.uses"/>

              </DIV>

            </TD></TR>

        </TABLE>

      </TD>

    </TR>

  </TABLE>

</xsl:template>


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     View-level templates, displayed when no clearlist item is selected
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<xsl:template match="item" mode="ucm.integration.snapshot.view">

  <H2>UCM のスナップショット インテグレーション ビュー</H2>

  <P> これは、<xsl:value-of select="projectname"/> プロジェクトのインテグレーション ストリームにアタッチされるビューです。 インテグレーション ストリームは、プロジェクトのビルドとテストに使用される共有バージョンを識別します。 共有バージョンは、すべてのプロジェクトの開発ビューからデリバーされます。 </P>

  <P>開発者は、インテグレーション ビューを使用して、他のチーム メンバーがデリバーした作業を確認します。また、デリバー操作中に自分の作業をテストします。</P>

  <P>プロジェクト マネージャーは、インテグレーション ビューを使用して次のことを行います。</P>

  <UL>

    <LI><P>開発の進行に伴って、新しいベースラインを作成します。 これにより、開発者は新しいベースラインにリベースして、プロジェクトの変化に対応できます。</P></LI>

    <LI><P>ベースラインをプロモートまたはデモートします。 プロモーション レベルによって、すべての開発者にベースラインの品質と安定性を示します。</P></LI>

    <LI><P>開発者のデリバー操作の完了に必要なサポートを提供します。</P></LI>
  
  </UL>

  <P>一連のソース ファイルを自分のビューにコピーするには、[<STRONG>更新</STRONG>] コマンドを使用します。　</P>

  <P><STRONG>メモ:  </STRONG>スナップショット ビューは自動更新されません。 ストリームに対する変更を確認するには、VS.NET <STRONG>ClearCase </STRONG> メニューの [<STRONG>更新</STRONG>] をクリックして、定期的にビューを更新する必要があります。</P>

</xsl:template>


<xsl:template match="item" mode="ucm.integration.dynamic.view">

  <H2>UCM の動的インテグレーション ビュー</H2>

  <P> これは、<xsl:value-of select="projectname"/> プロジェクト用のインテグレーション ビューです。</P>

  <P>インテグレーション ストリームは、プロジェクト全体またはプロジェクトの主な機能のビルドとテストに使用される共有バージョンを識別します。 共有バージョンは、プロジェクトの階層で下位にある、インテグレーション ストリームの子ストリームまたは開発ストリームの子ストリームからデリバーされます。 </P>

  <P>開発者は、インテグレーション ビューを使用して、他のチーム メンバーがデリバーした作業を確認します。また、デリバー操作中に自分の作業をテストします。</P>

  <P>プロジェクト マネージャーは、インテグレーション ビューを使用して次のことを行います。</P>

  <UL>

    <LI><P>開発の進行に伴って、新しいベースラインを作成します。 これにより、開発者は新しいベースラインにリベースして、プロジェクトの変化に対応できます。</P></LI>

    <LI><P>ベースラインをプロモートまたはデモートします。 プロモーション レベルによって、すべての開発者にベースラインの品質と安定性を示します。</P></LI>

    <LI><P>開発者のデリバー操作の完了に必要なサポートを提供します。</P></LI>

  </UL>

  <P><STRONG>メモ:  </STRONG>新バージョンのチェックインなど、VOB に変更があった場合、ビューのコンテンツは必ず自動的に更新されます。 ストリームに対するすべての変更を含むように表示を更新するには、[<STRONG>リフレッシュ</STRONG>] ボタンをクリックします。</P>

</xsl:template>


<xsl:template match="item" mode="ucm.development.snapshot.view">

  <H2>UCM のスナップショット開発ビュー</H2>

  <P>このビューは、<xsl:value-of select="projectname"/> プロジェクト開発ストリーム用の作業領域です。 UCM 開発ビューで、作業のフォーカスは直接ソースファイルに置かれるのではなく、アクティビティに置かれます。 </P>

  <P>この UCM プロジェクトに参加すると、ビューは一連の推奨ベースラインで初期化されます。 このベースラインは、1 つ以上のプロジェクト コンポーネントを開発するために必要なアクティビティを識別します。 また、このベースラインはそれらのコンポーネントに対して安定していると判断される一連のエレメント バージョンを識別します。</P>

  <P>定期的に、開発ストリームを親ストリームにある最新の推奨ベースラインにリベースしてください。 リベース操作を行うと、開発ストリームは一連の基本ベースラインの更新によって再構成されます。</P>

  <P>このビューで使用可能なアクティビティを表示するには、フォルダ ペインで [<STRONG>アクティビティ</STRONG>] をクリックします。 次に、アクティビティの横にあるチェックボックスを選択してビューのアクティビティを設定します。 これにより、ビューの ClearCase エレメントで実行する作業は、すべてプロジェクトの開発ストリームのアクティビティに関連付けられます。</P>

  <P>一連のソース ファイルを自分のビューにコピーするには、[<STRONG>更新</STRONG>] コマンドを使用します。　</P>

  <P><STRONG>メモ:  </STRONG>スナップショット ビューは自動更新されません。 ストリームに対する変更を確認するには、VS.NET <STRONG>ClearCase </STRONG> メニューの [<STRONG>更新</STRONG>] をクリックして、定期的にビューを更新する必要があります。</P>

</xsl:template>


<xsl:template match="item" mode="ucm.development.dynamic.view">

  <H2>UCM の動的開発ビュー</H2>

  <P>このビューは、<xsl:value-of select="projectname"/> プロジェクト開発ストリーム用の作業領域です。 UCM ビューでは、作業は必ずアクティビティと関連付けられています。 アクティビティは、開発タスクを完了するために作成したバージョンを識別する ClearCase オブジェクトです。 組織はアクティビティで実行されるタスクを定義します。</P>

  <P>このビューで使用可能なアクティビティを表示するには、フォルダ ペインで [<STRONG>アクティビティ</STRONG>] をクリックします。 次に、アクティビティの横にあるチェックボックスを選択してビューのアクティビティを設定します。 これにより、ビューの ClearCase エレメントで実行する作業は、すべてプロジェクトの開発ストリームのアクティビティに関連付けられます。</P>

  <P>定期的に、ビューを最新のベースラインにリベースしてください。 リベースによって、ビューは全体で共有するために統合、テスト、承認されたバージョンに更新されます。</P>

  <P>完了したアクティビティをプロジェクトのインテグレーション ストリームにデリバーすると、自分の作業がプロジェクトのほかのメンバーからも使用可能になります。</P>

  <P><STRONG>メモ:  </STRONG>新バージョンのチェックインなど、VOB に変更があった場合、ビューのコンテンツは必ず自動的に更新されます。 ストリームに対するすべての変更を含むように表示を更新するには、[<STRONG>リフレッシュ</STRONG>] ボタンをクリックします。</P>

</xsl:template>


<xsl:template match="item" mode="base.snapshot.view">

  <H2>スナップショット ビュー</H2>

  <P>プロジェクトのソース ファイルは、VOB (バージョン付きオブジェクト ベース) と呼ばれる 1 つ以上の ClearCase データ リポジトリに保存されます。 このビューによって、それらのファイルにアクセスできます。</P>

  <P>ファイルをチェックアウト、変更、再びチェックインするたびに、ClearCase が変更を記録する新バージョンを作成します。 バージョン管理は、チームが変更を管理し、ソースへのアクセスを調整できるようにするための機能の 1 つです。</P>

  <P>ビューには、ClearCase エレメントのほかにビュープライベート オブジェクトを含めることができます。これは、ClearCase VOB に保存されない通常の作業ファイルとフォルダです。 ビュープライベート ファイルまたはフォルダをビューに含めるには、それらを Windows エクスプローラから目的のビューにドラッグします。<!-- simply drag it into your view from your 
  Windows Explorer. --></P>

  <P>ClearCase エクスプローラ ショートカット ペイン、ツールバー、メニューによって、ビューで実行できるすべての ClearCase 操作にアクセスできます。 これ以外にも、多くの操作を Windows の標準機能を使用して実行することができます。 たとえば、HTML エレメントをダブルクリックすると Web ブラウザで文書を表示するなど、関連付けられた操作が実行されます。</P>

  <P>一連のソース ファイルを自分のビューにコピーするには、[<STRONG>更新</STRONG>] コマンドを使用します。　</P>
  
  <P><STRONG>メモ:  </STRONG>スナップショット ビューは自動更新されません。 VOB での変更を確認するには、VS.NET <STRONG>ClearCase </STRONG> メニューの [<STRONG>更新</STRONG>] をクリックして、定期的にビューを更新する必要があります。</P>

</xsl:template>


<xsl:template match="item" mode="base.dynamic.view">

  <H2>動的ビュー</H2>

  <P>プロジェクトのソース ファイルは、VOB (バージョン付きオブジェクト ベース) と呼ばれる 1 つ以上の ClearCase データ リポジトリに保存されます。 このビューによって、それらのソース ファイルにアクセスできます。</P>

  <P>ファイルをチェックアウト、変更、再びチェックインするたびに、ClearCase が変更を記録する新バージョンを作成します。 バージョン管理は、チームが変更を管理し、ソースへのアクセスを調整できるようにするための機能の 1 つです。</P>

  <P>ビューには、ClearCase エレメントのほかにビュープライベート オブジェクトを含めることができます。これは、ClearCase VOB に保存されない通常の作業ファイルとフォルダです。 ビュープライベート ファイルまたはフォルダをビューに含めるには、それらを Windows エクスプローラから目的のビューにドラッグします。 </P>

  <P><STRONG>メモ:  </STRONG>これは動的ビューであるため、新しいエレメントやバージョンの作成など、VOB に変更があった場合、ビューのコンテンツは必ず自動的に更新されます。 表示を更新して VOB に対するすべての変更を確認するには、ClearCase エクスプローラの [<STRONG>表示</STRONG>] メニューから [<STRONG>リフレッシュ</STRONG>] をクリックします。</P>

</xsl:template>


<xsl:template match="name" mode="item.props">
  <TR>

    <SPAN TITLE="ClearCase におけるエレメント名">

      <TH WIDTH="80" ALIGN="LEFT">名前:</TH>

    </SPAN> 

    <TD>

      <xsl:call-template name="breakline">

        <xsl:with-param name="txt" select="."/>

      </xsl:call-template>

    </TD>

  </TR>

</xsl:template>


<xsl:template match="name" mode="item.about">

  <xsl:choose>

    <xsl:when test="../@type='folder'">

      <xsl:choose>

        <xsl:when test="(.='lost+found')">            

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>

          は、ClearCase がビュー内の各 VOB の最上位に作成するフォルダです。</P>

          <P>ClearCase はこれを使用して、親のないエレメント (VOB のどのバージョンにもカタログされていないエレメント) を保存します。</P>

        </xsl:when>


        <xsl:when test="contains(ancestor::*/viewpath , 'lost+found')">
  
          <P>この項目は、以前バージョン管理下に置かれていた親のないフォルダです。 どの VOB にもフォルダのバージョンが存在しないため、ClearCase がここに移動しました。</P>

          <P>ClearCase は、一意の 16 進数による ID 番号を元のフォルダ名に追加します。</P>

        </xsl:when>


        <xsl:when test="../kind='ビュープライベート ディレクトリ'">  

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM> 

          は、ビュープライベート フォルダです。 これは、ClearCase VOB には表示されないことを意味しています。

          これが自分のビューの作業フォルダにあったとしても、このフォルダとすべての内容は、

          ファイル システム内にのみ存在します。 </P>

        </xsl:when>


        <xsl:when test="../kind='ディレクトリ バージョン'">  

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          バージョン管理されているフォルダです。 属性と内容は、ClearCase の管理下にあります。 </P>

        </xsl:when>


        <xsl:when test="../kind='Directory Element'">  

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          ClearCase 管理下にあるフォルダです。 </P>

        </xsl:when>


        <xsl:when test="../kind='VOB シンボリック リンク'">

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          エレメントではなく、異なる場所からターゲット フォルダへの参照です。 </P>

          <P>VOB シンボリック リンクは、UNIX のシンボル リンクと同様に振る舞います。</P>

        </xsl:when>


        <xsl:otherwise>

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM> 

          は、VOB (バージョン付きオブジェクト ベース) です。 これは、ClearCase 管理下で維持するファイルとディレクトリの

          すべてのバージョンのためのデータ リポジトリです。</P>

        </xsl:otherwise>

      </xsl:choose>

    </xsl:when>


    <xsl:when test="../@type[.='activity']">

      <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、UCM アクティビティです。</P>

      <P>アクティビティは、開発タスクを完了するために作成したバージョンを記録する ClearCase オブジェクトです。 </P>

    </xsl:when>


    <xsl:otherwise> <!-- default is 'file' -->

      <xsl:choose>

        <xsl:when test="contains(ancestor::*/viewpath , 'lost+found')">

          <P>この項目は、親のないエレメントです。 どの VOB にもエレメントのバージョンが存在しないため、ClearCase がほかのフォルダからここに移動しました。</P>

          <P>ClearCase は、一意の 16 進数による ID 番号を元のエレメント名に追加します。</P>

        </xsl:when>


        <xsl:when test="../kind='ビュープライベート ファイル'">

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          ClearCase ソース管理下にないビュープライベート ファイルです。</P>

        </xsl:when>


        <xsl:when test="../kind='VOB シンボリック リンク'">

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          エレメントではなく、異なる場所からターゲット ファイルへの参照です。 </P>

          <P>VOB シンボリック リンクは、UNIX のシンボル リンクと同様に振る舞います。</P>

        </xsl:when>


        <xsl:when test="../kind='ファイル'">

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          ClearCase によって作成された構成ファイルです。</P>

        </xsl:when>


        <xsl:when test="../kind='Derived Object Version'"> 

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          clearmake、omake ビルド、clearaudit セッションによって作成されたファイルです。</P>

        </xsl:when>


        <xsl:when test="../kind='View Derived Object'">

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          clearmake、omake ビルド、clearaudit セッションによって作成されたファイルです。</P>

        </xsl:when>


        <xsl:otherwise> <!-- File element version -->

          <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select="."/></EM>は、

          ClearCase ソース管理下にありバージョン管理されているファイルです。</P>

        </xsl:otherwise>

      </xsl:choose>

    </xsl:otherwise>

  </xsl:choose>

</xsl:template>


<xsl:template match="name" mode="item.uses">

  <xsl:choose>

    <xsl:when test="../@type='folder'">

      <xsl:choose>

        <xsl:when test="(.='lost+found')">            

          <P>このフォルダをチェックアウトすること、削除することはできませんが、ファイルを追加することは可能です。</P>

          <P>ビューの更新、リフレッシュの後、定期的にこのフォルダの内容をチェックし、クリーンアップしてディスク容量を節約してください。 </P>

          <P>lost+found フォルダのエレメントは、バージョン管理されているフォルダに移動されたか、削除された可能性があります。</P>

        </xsl:when>


        <xsl:when test="contains(ancestor::*/viewpath , 'lost+found')">
  
          <P>親のないフォルダは、チェックアウトできないという点でビュープライベート フォルダと似ています。 以下のオプションを検討してください。</P>

          <UL>

            <LI><P>このフォルダまたはフォルダ内のエレメントが必要な場合、それをビューのバージョン管理されている場所に移動するか、ほかの VOB に再配置することによって、バージョン管理下に置くことができます。</P></LI>

            <LI><P>フォルダは、所有者であるか、必要な権限を持っていれば削除することができます。</P></LI>

          </UL>

        </xsl:when>


        <xsl:when test="../kind='ビュープライベート ディレクトリ'">  

          <P>このフォルダは、ファイル システムのフォルダと同じように使用します。 たとえば、Windows エクスプローラでフォルダに直接アクセスすることができます。</P>

          <P>このフォルダをプロジェクトに追加すると決定した場合、いつでもフォルダを ClearCase ソース管理に追加できます。</P>

        </xsl:when>


        <xsl:when test="../kind='ディレクトリ バージョン'">  

          <P>ClearCase は、このフォルダを管理する機能があります。 たとえば、中にあるエレメントを作成または削除してフォルダを変更すると、ClearCase は自動的にフォルダをチェックアウトし、チェックインします。</P>

        </xsl:when>


        <xsl:when test="../kind='Directory Element'"></xsl:when>


        <xsl:when test="../kind='VOB シンボリック リンク'">

          <P>シンボリック リンク フォルダ内のエレメントはチェックアウトできません。エレメントが参照するターゲットにアクセスすることのみ可能です。</P>

          <P>シンボリック リンクは、所有者であるか、必要な権限を持っている場合のみ、削除できます。</P>

        </xsl:when>


        <xsl:otherwise>

          <P>ClearCase エクスプローラ ツールバーのドロップダウン リストを使用して、ビューにあるフォルダを移動します。 </P>

        </xsl:otherwise>

      </xsl:choose>

    </xsl:when>


    <xsl:when test="../@type='activity'"> 

      <P>アクティビティの作業を開始するには、まずアクティビティの横のチェックボックスを選択して、ビューに対するアクティビティを設定します。</P>

      <P>その後、作業のためにファイルをチェックアウトするときには、このアクティビティが [チェックアウト] ダイアログ ボックスのアクティビティ リストに設定されています。</P>

      <P>このアクティビティの作業準備ができたら、プロジェクトのインテグレーション ストリームにそれをデリバーできます。</P>

    </xsl:when>


    <xsl:otherwise> <!-- default is 'file' -->

      <xsl:choose>

        <xsl:when test="contains(ancestor::*/viewpath , 'lost+found')">

          <P>親のないファイルは、チェックアウトできないという点でビュープライベート ファイルと似ています。 以下のオプションを検討してください。</P>

          <UL>

            <LI><P>このファイルが必要な場合、それをビューのバージョン管理されているフォルダに移動するか、ほかの VOB に再配置することによって、バージョン管理下に置くことができます。</P></LI>

            <LI><P>フォルダは、所有者であるか、必要な権限を持っていれば削除することができます。</P></LI>

          </UL>

        </xsl:when>


        <xsl:when test="../kind='ビュープライベート ファイル'">

          <P>このファイルは、ファイル システムのファイルと同じように使用します。 たとえば、Windows エクスプローラやアプリケーションでファイルに直接アクセスすることができます。</P>

          <P>このファイルをプロジェクトに追加すると決定した場合、いつでもファイルを ClearCase ソース管理に追加できます。</P>

        </xsl:when>


        <xsl:when test="../kind='VOB シンボリック リンク'">

          <P>シンボリック リンクはチェックアウトできません。参照するエレメントにアクセスすることのみ可能です。 </P>

          <P>シンボリック リンクは、所有者であるか、必要な権限を持っている場合のみ、削除できます。</P>

        </xsl:when>


        <xsl:when test="../kind='ファイル'">

          <P>このファイルをチェックアウトまたは変更することはできません。</P>

        </xsl:when>


        <xsl:when test="../kind='Derived Object Version'"> 

          <P>各派生オブジェクトは、ビルドを記述するために ClearCase ビルド プログラムによって作成される構成レコードと関連付けられます。 </P>

        </xsl:when>


        <xsl:when test="../kind='View Derived Object'">

          <P>各派生オブジェクトは、ビルドを記述するために ClearCase ビルド プログラムによって作成される構成レコードと関連付けられます。 共有可能 DO は、ほかのビューによってウィンクインすることができます。 共有不可な DO は、明示的に使用可能にしない限り、ほかのビューによってウィンクインすることはできません。 </P>

        </xsl:when>


        <xsl:when test="../state='Checked Out (Reserved)'">

          <P>このファイルを変更し、新しいバージョンをチェックインする排他的な権限があります。</P>

          <P>ClearCase での作業を保存する準備ができたら、ファイルをチェックインします。</P>

          <P>新しいバージョンを作成しないと決定した場合は、いつでもチェックアウトを取り消すことができます。</P>

        </xsl:when>


        <xsl:when test="../state='Checked Out (Unreserved)'">

          <P>チェックアウトが予約済みでないため、ほかのユーザーがチェックアウトする可能性があります。 この場合、ページをチェックインする最初のユーザーが、新しいバージョンを作成します。 それ以外のすべてのユーザーは、各自の変更をチェックインする前に、最新バージョンを各自の作業対象にマージする必要があります。</P>

          <P>ClearCase での作業を保存する準備ができたら、ファイルをチェックインします。</P>

          <P>新しいバージョンを作成しないと決定した場合は、いつでもチェックアウトを取り消すことができます。</P>

        </xsl:when>

        <xsl:otherwise> <!-- File element version -->

          <xsl:choose>

            <xsl:when test="../state='Hijacked'">

              <P>項目を右クリックして、ショートカット メニューから [<b>ハイジャックされたファイルの取り消し</b>] を選択します。  </P>

              <P>ハイジャックされたファイルの取り消しを行うと、ClearCase はハイジャックされたファイルの名前を新しい拡張子 .keep を使用して変更し、ビューが VOB から選択したバージョンをロードします。 </P>

            </xsl:when>

            <xsl:otherwise>

              <P>バージョン管理されているファイルで作業するには、次のようにファイルをチェックアウトします。 詳細ペイン内のエレメントを右クリックし、ショートカット メニューから [<STRONG>チェックアウト</STRONG>] を選択します。 ClearCase は、ビューで作業するためのプライベート コピーを作成します。</P>

              <P>ファイルの変更後、ファイルをチェックインして VOB に新しいバージョンを保存してください。</P>

            </xsl:otherwise>

          </xsl:choose>

        </xsl:otherwise>

      </xsl:choose>

    </xsl:otherwise>

  </xsl:choose>

</xsl:template>


<xsl:template match="viewtag" mode="item.props">

  <TR>

    <SPAN TITLE="ClearCase におけるビューの修飾名">
  
      <TH WIDTH="80" ALIGN="LEFT">ビュー タグ: </TH>

    </SPAN>                 

    <TD>

      <xsl:call-template name="breakline">

        <xsl:with-param name="txt" select="."/>

      </xsl:call-template>

    </TD>

  </TR>

</xsl:template>


<xsl:template match="viewtag" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="viewtag" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="viewpath" mode="item.props">

  <TR>

    <SPAN TITLE="ビュー ファイルの作業が可能なフォルダ">

      <TH WIDTH="80" ALIGN="LEFT">ビュー パス: </TH>

    </SPAN>                 
  
    <TD>

      <xsl:call-template name="breakline">

        <xsl:with-param name="txt" select="."/>

      </xsl:call-template>

    </TD>                

  </TR>

</xsl:template>


<xsl:template match="viewpath" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="viewpath" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="snapshot" mode="item.props"><!-- No display --></xsl:template>


<xsl:template match="snapshot" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="snapshot" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="ucm" mode="item.props"><!-- No display --></xsl:template>


<xsl:template match="ucm" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="ucm" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="integration" mode="item.props"><!-- No display --></xsl:template>


<xsl:template match="integration" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="integration" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="projectname" mode="item.props">

  <xsl:if test="../ucm[.='1']">

    <TR>

      <SPAN TITLE="現在作業している UCM プロジェクト">

        <TH WIDTH="80" ALIGN="LEFT">UCM プロジェクト: </TH>

      </SPAN> 
                
      <TD>

        <xsl:value-of select="."/>

      </TD>

    </TR>

  </xsl:if>

</xsl:template>


<xsl:template match="projectname" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="projectname" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="activityset" mode="item.props"><!-- No display --></xsl:template>


<xsl:template match="activityset" mode="item.about">

  <xsl:if test=".='1'">

    <p>これはストリーム内の現在のアクティビティです。</p>

  </xsl:if>

</xsl:template>


<xsl:template match="activityset" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="cqonlyactivity" mode="item.props"><!-- No display --></xsl:template>


<xsl:template match="cqonlyactivity" mode="item.about">

  <xsl:if test=".='1'">

    <p>この ClearCase 項目は現在のストリームではチェックアウトされていません。 したがって、これはまだ UCM アクティビティではありません。</p>

  </xsl:if>

</xsl:template>


<xsl:template match="cqonlyactivity" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="fullpathname" mode="item.props">

  <!-- Redundant, don't display anything -->

</xsl:template>


<xsl:template match="fullpathname" mode="item.about">

</xsl:template>


<xsl:template match="fullpathname" mode="item.uses">

</xsl:template>


<xsl:template match="state" mode="item.props">

  <TR>

    <SPAN TITLE="変わる可能性のある現在のエレメントの状態">

      <TH WIDTH="80" ALIGN="LEFT">状態: </TH>

    </SPAN>                 

    <TD>

      <xsl:value-of select="."/>

    </TD>                

  </TR>

</xsl:template>


<xsl:template match="state" mode="item.about">

    <xsl:if test=".='Checked Out (Reserved)'">

       <P>現在、<xsl:value-of select="../name"/>をチェックアウトしています。 また、これは予約済みにして、次のバージョンを自分だけが作成できるようにしてあります。</P>

    </xsl:if>

    <xsl:if test=".='Checked Out (Unreserved)'">

       <P>現在、<xsl:value-of select="../name"/>をチェックアウトしていますが、予約済みではありません。 したがって、ほかの誰かがエレメントをチェックアウトする可能性があります。</P>

    </xsl:if>

    <xsl:if test=".='Hijacked'">

      <P>この項目は、現在ハイジャックされています。 チェックアウトされずに変更されています。 ハイジャックされたファイルは、ClearCase の直接の管理から外れます。 </P>

      <P>問題の解消方法についての簡単な情報を見るには、[使用法] タブをクリックします。</P>

    </xsl:if>

</xsl:template>


<xsl:template match="state" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="kind" mode="item.props">

  <TR>

    <SPAN TITLE="ClearCase オブジェクトの種類">

      <TH WIDTH="80" ALIGN="LEFT">種類: </TH>

    </SPAN> 
               
    <TD>

      <xsl:value-of select="."/>

    </TD>
                
  </TR>
</xsl:template>


<xsl:template match="kind" mode="item.about">
 
</xsl:template>


<xsl:template match="kind" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="modified" mode="item.props">

  <TR>

    <SPAN TITLE="エレメントが変更された最新の日付">

      <TH WIDTH="80" ALIGN="LEFT">変更:  </TH>

    </SPAN> 
            
    <TD>

      <xsl:value-of select="."/>

    </TD>                

  </TR>

</xsl:template>


<xsl:template match="modified" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="modified" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="version" mode="item.props">

  <xsl:if test='(../kind[.!="ビュープライベート ディレクトリ"])'>

    <xsl:if test='(../kind[.!="ビュープライベート ファイル"])'> 

      <TR>

        <SPAN TITLE="エレメントのバージョン">

          <TH WIDTH="80" ALIGN="LEFT">バージョン:  </TH>

        </SPAN> 
                
        <TD>

          <xsl:value-of select="."/>

        </TD>                

      </TR>

    </xsl:if>

  </xsl:if>

</xsl:template>


<xsl:template match="version" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="version" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template match="annotations" mode="item.props">

  <!-- Omit -->

</xsl:template>


<xsl:template match="annotations" mode="item.about">

  <xsl:choose>

    <xsl:when test=".='eclipsed'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>このエレメントは見えなくなっています。 ビュー内に同じ名前を持つビュープライベート オブジェクトが存在するため、エレメントのバージョンが選択されていません。</P>

    </xsl:when>


    <xsl:when test=".='checkedout but eclipsed'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>エレメントは、このビューではチェックアウト済みですが、CHECKEDOUT 構成仕様規則がありません。したがって、チェックアウト済みのバージョンは、このビューでは見えません。</P>

    </xsl:when>


    <xsl:when test=".='not loaded, checkedout but removed'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>エレメントはこのビューでチェックアウトされましたが、後でビュープライベート ファイルが削除されました。</P>

    </xsl:when>


    <xsl:when test=".='not loaded'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>エレメントはスナップショット ビューにロードされていません。</P>

    </xsl:when>


    <xsl:when test=".='loaded but missing'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>エレメントのバージョンがビューにロードされましたが、ビューでファイルが削除されたか、ファイルの名前が変更されています。</P>

    </xsl:when>


    <xsl:when test=".='hijacked'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>このバージョンはハイジャックされています。 チェックアウトされずに変更されています。</P>

    </xsl:when>


<!-- Uses unknown, omit until developed in "item.uses" mode

    <xsl:when test=".='no version selected'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is not selected by any config spec rule, or is selected by a -none config spec rule.</P>

    </xsl:when>


    <xsl:when test=".='error on reference'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is selected by an -error config spec rule.</P>

    </xsl:when>


    <xsl:when test=".='no config record '">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object's data container is still stored in the view, but the derived object in the VOB database has been deleted.</P>

    </xsl:when>


    <xsl:when test=".='disputed checkout'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is considered to be checked out by the view server but is not so indicated in the VOB database.</P>

    </xsl:when>


    <xsl:when test=".='removed with white out'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object was winked in by, and is still referenced by, the current view, but it has been removed from the VOB database.</P>

    </xsl:when>


    <xsl:when test=".='overridden'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is loaded in the snapshot view, but its file type is not the same as the corresponding object in the VOB; or the element is not loaded in the snapshot view, but an object with the same name exists in the view.</P>

    </xsl:when>


    <xsl:when test=".='special selection'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version you checked in is not the version that the config spec selects from the VOB.</P>

    </xsl:when>


    <xsl:when test=".='nocheckout'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version hijacked in the view is no longer the version the config spec selects from the VOB.</P>

    </xsl:when>


    <xsl:when test=".='deleted version'">

      <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version currently in the view has been removed from the VOB.</P>

    </xsl:when>

-->

  </xsl:choose>

</xsl:template>


<xsl:template match="annotations" mode="item.uses">

  <xsl:choose>

    <xsl:when test=".='eclipsed'">

      <P>見えなくなっている状態を修正するには、ビュープライベート エレメントをビューから削除するか、移動します。 次に、[<STRONG>表示</STRONG>] から [<STRONG>リフレッシュ</STRONG>] をクリックして表示を更新します。</P>

    </xsl:when>


    <xsl:when test=".='checkedout but eclipsed'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>チェックアウトされたが見えなくなっている状態を修正するには、ビューの構成仕様に CHECKEDOUT 規則を追加してから、ビューを再起動または再ロードします。</P>

    </xsl:when>


    <xsl:when test=".='not loaded, checkedout but removed'">

      <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>チェックアウトされたが削除された状態を修正するには、[<STRONG>ClearCase</STRONG>] から [<STRONG>チェックアウトの取り消し</STRONG>] をクリックしてチェックアウトを取り消すか、削除されたファイルを復元します。</P>

    </xsl:when>


    <xsl:when test=".='not loaded'">

                <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>エレメントをロードするには、[ベース ClearCase] の [ツール] タブにある [<STRONG>ビュー プロパティの編集</STRONG>] をクリックしてからビューのロード規則を編集するか、 [<STRONG>環境</STRONG>] から [<STRONG>ロードされていないエレメントの表示</STRONG>] をクリックして、ロードされていないエレメントの表示を抑制します。 </P>

    </xsl:when>


    <xsl:when test=".='loaded but missing'">

                <P><EM STYLE="font-style: normal; font-weight: bold">メモ:  </EM>ロードされたが見つからない状態を修正するには、欠落しているファイルを復元するか、ファイルをビューからアンロードします。</P>

    </xsl:when>


    <xsl:when test=".='hijacked'">

      <!-- Already covered by state template -->
      
    </xsl:when>


<!-- No text developed yet

    <xsl:when test=".='no version selected'"></xsl:when>


    <xsl:when test=".='error on reference'"></xsl:when>


    <xsl:when test=".='no config record '"></xsl:when>


    <xsl:when test=".='disputed checkout'"></xsl:when>


    <xsl:when test=".='removed with white out'"></xsl:when>


    <xsl:when test=".='overridden'"></xsl:when>


    <xsl:when test=".='special selection'"></xsl:when>


    <xsl:when test=".='nocheckout'"></xsl:when>


    <xsl:when test=".='deleted version'"></xsl:when>

-->

  </xsl:choose>


</xsl:template>


<xsl:template match="rule" mode="item.props">

  <xsl:if test='(../kind[.!="ビュープライベート ディレクトリ"])'>

    <xsl:if test='(../kind[.!="ビュープライベート ファイル"])'>

      <TR>

        <SPAN TITLE="このエレメントに適用される構成仕様の規則">

          <TH WIDTH="80" ALIGN="LEFT">規則:  </TH>

        </SPAN> 
                
        <TD>

          <xsl:value-of select="."/>

        </TD>                

      </TR>

    </xsl:if>

  </xsl:if>

</xsl:template>


<xsl:template match="rule" mode="item.about"><!-- No display --></xsl:template>


<xsl:template match="rule" mode="item.uses"><!-- No display --></xsl:template>


<xsl:template name="breakline">

  <xsl:param name="txt"/>

  <xsl:param name="width" select="30"/>

  <xsl:if test="$txt">

    <xsl:variable name="real-width">

      <xsl:call-template name="tune-width">

  	  <xsl:with-param name="txt" select="$txt"/>

        <xsl:with-param name="width" select="$width"/>

        <xsl:with-param name="def" select="$width"/>
	
      </xsl:call-template>

    </xsl:variable>

    <xsl:value-of select="substring($txt, 1, $real-width)"/>

    <!-- <xsl:text>&#10;</xsl:text> -->

    <br/>

    <xsl:call-template name="breakline">

      <xsl:with-param name="txt" select="substring($txt,$real-width + 1)"/>

      <xsl:with-param name="width" select="$width"/>

    </xsl:call-template>

  </xsl:if>

</xsl:template>


<xsl:template name="tune-width">

  <xsl:param name="txt"/>

  <xsl:param name="width"/>

  <xsl:param name="def"/>

  <xsl:choose>

    <xsl:when test="$width = 0">

      <xsl:value-of select="$def"/>

    </xsl:when>

    <xsl:otherwise>

      <xsl:choose>

        <xsl:when test="substring($txt, $width, 1 ) = ' ' or '\n'">

          <xsl:value-of select="$width"/>

        </xsl:when>

        <xsl:otherwise>

          <xsl:call-template name="tune-width">

            <xsl:with-param name="txt" select="$txt"/>

            <xsl:with-param name="width" select="$width - 1"/>

            <xsl:with-param name="def" select="$def"/>

          </xsl:call-template>

        </xsl:otherwise>

      </xsl:choose>

    </xsl:otherwise>

  </xsl:choose>

</xsl:template>

</xsl:stylesheet>